@@ -4,7 +4,7 @@ Contains a panel to manage unicode decoding/encoding errors.
 """
 from pyqode.core.api.panel import Panel
 from pyqode.core.api.decoration import TextDecoration
-from pyqode.qt import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 
 
 class EncodingPanel(Panel):
@@ -222,4 +222,4 @@ if __name__ == '__main__':
     edit.show()
     simulate_open()
     QtCore.QTimer.singleShot(5000, simulate_save)
-    app.exec_()
+    app.exec_()
\ No newline at end of file
