@@ -9,7 +9,7 @@ import platform
 import shutil
 import subprocess
 from pathspec import PathSpec
-from pyqode.qt import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 from pyqode.core import icons
 
 
@@ -815,4 +815,4 @@ class FileSystemContextMenu(QtWidgets.QMenu):
         cmd = cls.get_file_explorer_command()
         cmd[-1] = cmd[-1].format(path)
         _logger().info('show file in explorer: %s' % cmd)
-        subprocess.Popen(cmd)
+        subprocess.Popen(cmd)
\ No newline at end of file
