@@ -9,7 +9,7 @@ import io
 import uuid
 import weakref
 
-from pyqode.qt import QtCore, QtWidgets, QtGui
+from qtpy import QtCore, QtWidgets, QtGui
 from pyqode.core.api import utils
 from pyqode.core import icons
 from pyqode.core.cache import Cache
@@ -139,7 +139,12 @@ class DraggableTabBar(TabBar):
     def dropEvent(self, event):
         # drop a tab in a split (may be the same split or another one).
         m = event.mimeData()
-        index = self.tabAt(event.pos())
+        try:
+            pos = event.position().toPoint()
+        except AttributeError:
+            # PyQt5 fallback
+            pos = event.pos()
+        index = self.tabAt(pos)
         # Tell interested objects that a tab should be moved.
         if m.tab != self.parent().widget(index):
             self.tab_move_request.emit(m.tab, index)
@@ -724,7 +729,12 @@ class BaseTabWidget(QtWidgets.QTabWidget):
 
     def dropEvent(self, event):
         m = event.mimeData()
-        index = self.tabBar().tabAt(event.pos())
+        try:
+            pos = event.position().toPoint()
+        except AttributeError:
+            # PyQt5 fallback
+            pos = event.pos()
+        index = self.tabBar().tabAt(pos)
         # Tell interested objects that a tab should be moved.
         if m.tab != self.widget(index):
             self._on_tab_move_request(m.tab, index)
@@ -1044,10 +1054,6 @@ class SplittableTabWidget(QtWidgets.QSplitter):
         clone = base.split()
         if not clone:
             return
-        if orientation == int(QtCore.Qt.Horizontal):
-            orientation = QtCore.Qt.Horizontal
-        else:
-            orientation = QtCore.Qt.Vertical
         self.setOrientation(orientation)
         splitter = self._make_splitter()
         splitter.show()
